@@ -11,14 +11,12 @@ use WWW::UsePerl::Journal;
 print "Supply usernames to look up on the command line\n"
     if (~~@ARGV == 0);
 
-foreach my $user (@ARGV)
-{
+for my $user (@ARGV) {
     my $journal = WWW::UsePerl::Journal->new($user);
     my %entries = $journal->entryhash;
     my %count;
 
-    foreach my $entrynum (sort keys %entries)
-    {
+    for my $entrynum (sort keys %entries) {
         my $entry = $entries{$entrynum};
         my $date = $entry->date;
         my($month, $year) = ($date->mon, $date->year);
